==> monaco-vscode-debug-service-override-11.1.2.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/debugTaskRunner.js <==
import { __decorate, __param } from 'vscode/external/tslib/tslib.es6.js';
import { Action } from 'vscode/vscode/vs/base/common/actions';
import { disposableTimeout } from 'vscode/vscode/vs/base/common/async';
import { CancellationTokenSource } from 'vscode/vscode/vs/base/common/cancellation';
import { createErrorWithActions } from 'vscode/vscode/vs/base/common/errorMessage';
import { Event, Emitter } from 'vscode/vscode/vs/base/common/event';
import { DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity$1 from 'vscode/vscode/vs/base/common/severity';
import { localize } from 'vscode/vscode/vs/nls';
import { ICommandService } from 'vscode/vscode/vs/platform/commands/common/commands.service';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';
import { IDialogService } from 'vscode/vscode/vs/platform/dialogs/common/dialogs.service';
import { MarkerSeverity } from 'vscode/vscode/vs/platform/markers/common/markers';
import { IMarkerService } from 'vscode/vscode/vs/platform/markers/common/markers.service';
import { IProgressService } from 'vscode/vscode/vs/platform/progress/common/progress.service';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { DEBUG_CONFIGURE_COMMAND_ID, DEBUG_CONFIGURE_LABEL } from '@codingame/monaco-vscode-debug-notebook-common/vscode/vs/workbench/contrib/debug/browser/debugCommands';
import { Markers } from 'vscode/vscode/vs/workbench/contrib/markers/common/markers';
import { CustomTask, ConfiguringTask } from 'vscode/vscode/vs/workbench/contrib/tasks/common/tasks';
import { ITaskService } from 'vscode/vscode/vs/workbench/contrib/tasks/common/taskService.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';

const onceFilter = (event, filter) => Event.once(Event.filter(event, filter));
const DEBUG_TASK_ERROR_CHOICE_KEY = 'debug.taskerrorchoice';
const ABORT_LABEL = ( localize(5805, "Abort"));
const DEBUG_ANYWAY_LABEL = ( localize(5806, "&&Debug Anyway"));
const DEBUG_ANYWAY_LABEL_NO_MEMO = ( localize(5807, "Debug Anyway"));
let DebugTaskRunner = class DebugTaskRunner {
    constructor(taskService, markerService, configurationService, viewsService, dialogService, storageService, commandService, progressService) {
        this.taskService = taskService;
        this.markerService = markerService;
        this.configurationService = configurationService;
        this.viewsService = viewsService;
        this.dialogService = dialogService;
        this.storageService = storageService;
        this.commandService = commandService;
        this.progressService = progressService;
        this.globalCancellation = ( (new CancellationTokenSource()));
    }
    cancel() {
        this.globalCancellation.dispose(true);
        this.globalCancellation = ( (new CancellationTokenSource()));
    }
    dispose() {
        this.globalCancellation.dispose(true);
    }
    async runTaskAndCheckErrors(root, taskId) {
        try {
            const taskSummary = await this.runTask(root, taskId, this.globalCancellation.token);
            if (taskSummary && (taskSummary.exitCode === undefined || taskSummary.cancelled)) {
                return 0 ;
            }
            const errorCount = taskId ? this.markerService.read({ severities: MarkerSeverity.Error, take: 2 }).length : 0;
            const successExitCode = taskSummary && taskSummary.exitCode === 0;
            const failureExitCode = taskSummary && taskSummary.exitCode !== 0;
            const onTaskErrors = this.configurationService.getValue('debug').onTaskErrors;
            if (successExitCode || onTaskErrors === 'debugAnyway' || (errorCount === 0 && !failureExitCode)) {
                return 1 ;
            }
            if (onTaskErrors === 'showErrors') {
                await this.viewsService.openView(Markers.MARKERS_VIEW_ID, true);
                return Promise.resolve(0 );
            }
            if (onTaskErrors === 'abort') {
                return Promise.resolve(0 );
            }
            const taskLabel = typeof taskId === 'string' ? taskId : taskId ? taskId.name : '';
            const message = errorCount > 1
                ? ( localize(5808, "Errors exist after running preLaunchTask '{0}'.", taskLabel))
                : errorCount === 1
                    ? ( localize(5809, "Error exists after running preLaunchTask '{0}'.", taskLabel))
                    : taskSummary && typeof taskSummary.exitCode === 'number'
                        ? ( localize(
                5810,
                "The preLaunchTask '{0}' terminated with exit code {1}.",
                taskLabel,
                taskSummary.exitCode
            ))
                        : ( localize(5811, "The preLaunchTask '{0}' terminated.", taskLabel));
            let DebugChoice;
            ( ((function(DebugChoice) {
                DebugChoice[DebugChoice["DebugAnyway"] = 1] = "DebugAnyway";
                DebugChoice[DebugChoice["ShowErrors"] = 2] = "ShowErrors";
                DebugChoice[DebugChoice["Cancel"] = 0] = "Cancel";
            })(DebugChoice || (DebugChoice = {}))));
            const { result, checkboxChecked } = await this.dialogService.prompt({
                type: Severity$1.Warning,
                message,
                buttons: [
                    {
                        label: DEBUG_ANYWAY_LABEL,
                        run: () => DebugChoice.DebugAnyway
                    },
                    {
                        label: ( localize(5812, "&&Show Errors")),
                        run: () => DebugChoice.ShowErrors
                    }
                ],
                cancelButton: {
                    label: ABORT_LABEL,
                    run: () => DebugChoice.Cancel
                },
                checkbox: {
                    label: ( localize(5813, "Remember my choice in user settings")),
                }
            });
            const debugAnyway = result === DebugChoice.DebugAnyway;
            const abort = result === DebugChoice.Cancel;
            if (checkboxChecked) {
                this.configurationService.updateValue('debug.onTaskErrors', result === DebugChoice.DebugAnyway ? 'debugAnyway' : abort ? 'abort' : 'showErrors');
            }
            if (abort) {
                return Promise.resolve(0 );
            }
            if (debugAnyway) {
                return 1 ;
            }
            await this.viewsService.openView(Markers.MARKERS_VIEW_ID, true);
            return Promise.resolve(0 );
        }
        catch (err) {
            const taskConfigureAction = this.taskService.configureAction();
            const choiceMap = JSON.parse(this.storageService.get(DEBUG_TASK_ERROR_CHOICE_KEY, 1 , '{}'));
            let choice = -1;
            let DebugChoice;
            ( ((function(DebugChoice) {
                DebugChoice[DebugChoice["DebugAnyway"] = 0] = "DebugAnyway";
                DebugChoice[DebugChoice["ConfigureTask"] = 1] = "ConfigureTask";
                DebugChoice[DebugChoice["Cancel"] = 2] = "Cancel";
            })(DebugChoice || (DebugChoice = {}))));
            if (choiceMap[err.message] !== undefined) {
                choice = choiceMap[err.message];
            }
            else {
                const { result, checkboxChecked } = await this.dialogService.prompt({
                    type: Severity$1.Error,
                    message: err.message,
                    buttons: [
                        {
                            label: ( localize(5806, "&&Debug Anyway")),
                            run: () => DebugChoice.DebugAnyway
                        },
                        {
                            label: taskConfigureAction.label,
                            run: () => DebugChoice.ConfigureTask
                        }
                    ],
                    cancelButton: {
                        run: () => DebugChoice.Cancel
                    },
                    checkbox: {
                        label: ( localize(5814, "Remember my choice for this task"))
                    }
                });
                choice = result;
                if (checkboxChecked) {
                    choiceMap[err.message] = choice;
                    this.storageService.store(DEBUG_TASK_ERROR_CHOICE_KEY, JSON.stringify(choiceMap), 1 , 1 );
                }
            }
            if (choice === DebugChoice.ConfigureTask) {
                await taskConfigureAction.run();
            }
            return choice === DebugChoice.DebugAnyway ? 1  : 0 ;
        }
    }
    async runTask(root, taskId, token = this.globalCancellation.token) {
        if (!taskId) {
            return Promise.resolve(null);
        }
        if (!root) {
            return Promise.reject(( (new Error(( localize(
                5815,
                "Task '{0}' can not be referenced from a launch configuration that is in a different workspace folder.",
                typeof taskId === 'string' ? taskId : taskId.type
            ))))));
        }
        const task = await this.taskService.getTask(root, taskId);
        if (!task) {
            const errorMessage = typeof taskId === 'string'
                ? ( localize(5816, "Could not find the task '{0}'.", taskId))
                : ( localize(5817, "Could not find the specified task."));
            return Promise.reject(createErrorWithActions(errorMessage, [( (new Action(
                DEBUG_CONFIGURE_COMMAND_ID,
                DEBUG_CONFIGURE_LABEL,
                undefined,
                true,
                () => this.commandService.executeCommand(DEBUG_CONFIGURE_COMMAND_ID)
            )))]));
        }
        let taskStarted = false;
        const store = ( (new DisposableStore()));
        const getTaskKey = (t) => t.getKey() ?? t.getMapKey();
        const taskKey = getTaskKey(task);
        const inactivePromise = ( (new Promise(
            (resolve) => store.add(onceFilter(this.taskService.onDidStateChange, e => {
                return (e.kind === "inactive"
                    || (e.kind === "processEnded"  && e.exitCode === undefined))
                    && getTaskKey(e.__task) === taskKey;
            })(e => {
                taskStarted = true;
                resolve(e.kind === "processEnded"  ? { exitCode: e.exitCode } : null);
            }))
        )));
        store.add(onceFilter(this.taskService.onDidStateChange, e => (((e.kind === "active") ) || ((e.kind === "dependsOnStarted") )) && getTaskKey(e.__task) === taskKey)(() => {
            taskStarted = true;
        }));
        const didAcquireInput = store.add(( (new Emitter())));
        store.add(onceFilter(this.taskService.onDidStateChange, e => ((e.kind === "acquiredInput") ) && getTaskKey(e.__task) === taskKey)(() => didAcquireInput.fire()));
        const taskDonePromise = this.taskService.getActiveTasks().then(async (tasks) => {
            if (tasks.find(t => getTaskKey(t) === taskKey)) {
                didAcquireInput.fire();
                const busyTasks = await this.taskService.getBusyTasks();
                if (busyTasks.find(t => getTaskKey(t) === taskKey)) {
                    taskStarted = true;
                    return inactivePromise;
                }
                return Promise.resolve(null);
            }
            const taskPromise = this.taskService.run(task);
            if (task.configurationProperties.isBackground) {
                return inactivePromise;
            }
            return taskPromise.then(x => x ?? null);
        });
        const result = ( (new Promise((resolve, reject) => {
            taskDonePromise.then(result => {
                taskStarted = true;
                resolve(result);
            }, error => reject(error));
            store.add(token.onCancellationRequested(() => {
                resolve({ exitCode: undefined, cancelled: true });
                this.taskService.terminate(task).catch(() => { });
            }));
            store.add(didAcquireInput.event(() => {
                const waitTime = task.configurationProperties.isBackground ? 5000 : 10000;
                store.add(disposableTimeout(() => {
                    if (!taskStarted) {
                        const errorMessage = ( localize(
                            5818,
                            "The task '{0}' has not exited and doesn't have a 'problemMatcher' defined. Make sure to define a problem matcher for watch tasks.",
                            typeof taskId === 'string' ? taskId : JSON.stringify(taskId)
                        ));
                        reject({ severity: Severity$1.Error, message: errorMessage });
                    }
                }, waitTime));
                const hideSlowPreLaunchWarning = this.configurationService.getValue('debug').hideSlowPreLaunchWarning;
                if (!hideSlowPreLaunchWarning) {
                    store.add(disposableTimeout(() => {
                        const message = ( localize(
                            5819,
                            "Waiting for preLaunchTask '{0}'...",
                            task.configurationProperties.name
                        ));
                        const buttons = [DEBUG_ANYWAY_LABEL_NO_MEMO, ABORT_LABEL];
                        const canConfigure = task instanceof CustomTask || task instanceof ConfiguringTask;
                        if (canConfigure) {
                            buttons.splice(1, 0, ( localize(5820, "Configure Task")));
                        }
                        this.progressService.withProgress({ location: 15 , title: message, buttons }, () => result.catch(() => { }), (choice) => {
                            if (choice === undefined) ;
                            else if (choice === 0) {
                                resolve({ exitCode: 0 });
                            }
                            else {
                                resolve({ exitCode: undefined, cancelled: true });
                                this.taskService.terminate(task).catch(() => { });
                                if (canConfigure && choice === 1) {
                                    this.taskService.openConfig(task);
                                }
                            }
                        });
                    }, 10_000));
                }
            }));
        })));
        return result.finally(() => store.dispose());
    }
};
DebugTaskRunner = ( (__decorate([
    ( (__param(0, ITaskService))),
    ( (__param(1, IMarkerService))),
    ( (__param(2, IConfigurationService))),
    ( (__param(3, IViewsService))),
    ( (__param(4, IDialogService))),
    ( (__param(5, IStorageService))),
    ( (__param(6, ICommandService))),
    ( (__param(7, IProgressService)))
], DebugTaskRunner)));

export { DebugTaskRunner };

==> monaco-vscode-debug-service-override-12.0.0.tgz: package/vscode/src/vs/workbench/contrib/debug/browser/debugTaskRunner.js <==

import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Action } from 'vscode/vscode/vs/base/common/actions';
import { disposableTimeout } from 'vscode/vscode/vs/base/common/async';
import { CancellationTokenSource } from 'vscode/vscode/vs/base/common/cancellation';
import { createErrorWithActions } from 'vscode/vscode/vs/base/common/errorMessage';
import { Event, Emitter } from 'vscode/vscode/vs/base/common/event';
import { DisposableStore } from 'vscode/vscode/vs/base/common/lifecycle';
import Severity from 'vscode/vscode/vs/base/common/severity';
import { localize } from 'vscode/vscode/vs/nls';
import { ICommandService } from 'vscode/vscode/vs/platform/commands/common/commands.service';
import { IConfigurationService } from 'vscode/vscode/vs/platform/configuration/common/configuration.service';
import { IDialogService } from 'vscode/vscode/vs/platform/dialogs/common/dialogs.service';
import { MarkerSeverity } from 'vscode/vscode/vs/platform/markers/common/markers';
import { IMarkerService } from 'vscode/vscode/vs/platform/markers/common/markers.service';
import { ProgressLocation } from 'vscode/vscode/vs/platform/progress/common/progress';
import { IProgressService } from 'vscode/vscode/vs/platform/progress/common/progress.service';
import { StorageScope, StorageTarget } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import { DEBUG_CONFIGURE_COMMAND_ID, DEBUG_CONFIGURE_LABEL } from '@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/debugCommands';
import { Markers } from '@codingame/monaco-vscode-2448342b-297f-5823-9f41-f18eef0f6ee8-common/vscode/vs/workbench/contrib/markers/common/markers';
import { TaskEventKind, CustomTask, ConfiguringTask } from 'vscode/vscode/vs/workbench/contrib/tasks/common/tasks';
import { ITaskService } from 'vscode/vscode/vs/workbench/contrib/tasks/common/taskService.service';
import { IViewsService } from 'vscode/vscode/vs/workbench/services/views/common/viewsService.service';

const onceFilter = (event, filter) => Event.once(Event.filter(event, filter));
var TaskRunResult;
(function (TaskRunResult) {
    TaskRunResult[TaskRunResult["Failure"] = 0] = "Failure";
    TaskRunResult[TaskRunResult["Success"] = 1] = "Success";
})(TaskRunResult || (TaskRunResult = {}));
const DEBUG_TASK_ERROR_CHOICE_KEY = 'debug.taskerrorchoice';
const ABORT_LABEL = ( localize(5375, "Abort"));
const DEBUG_ANYWAY_LABEL = ( localize(5376, "&&Debug Anyway"));
const DEBUG_ANYWAY_LABEL_NO_MEMO = ( localize(5377, "Debug Anyway"));
let DebugTaskRunner = class DebugTaskRunner {
    constructor(taskService, markerService, configurationService, viewsService, dialogService, storageService, commandService, progressService) {
        this.taskService = taskService;
        this.markerService = markerService;
        this.configurationService = configurationService;
        this.viewsService = viewsService;
        this.dialogService = dialogService;
        this.storageService = storageService;
        this.commandService = commandService;
        this.progressService = progressService;
        this.globalCancellation = ( new CancellationTokenSource());
    }
    cancel() {
        this.globalCancellation.dispose(true);
        this.globalCancellation = ( new CancellationTokenSource());
    }
    dispose() {
        this.globalCancellation.dispose(true);
    }
    async runTaskAndCheckErrors(root, taskId) {
        try {
            const taskSummary = await this.runTask(root, taskId, this.globalCancellation.token);
            if (taskSummary && (taskSummary.exitCode === undefined || taskSummary.cancelled)) {
                return TaskRunResult.Failure;
            }
            const errorCount = taskId ? this.markerService.read({ severities: MarkerSeverity.Error, take: 2 }).length : 0;
            const successExitCode = taskSummary && taskSummary.exitCode === 0;
            const failureExitCode = taskSummary && taskSummary.exitCode !== 0;
            const onTaskErrors = this.configurationService.getValue('debug').onTaskErrors;
            if (successExitCode || onTaskErrors === 'debugAnyway' || (errorCount === 0 && !failureExitCode)) {
                return TaskRunResult.Success;
            }
            if (onTaskErrors === 'showErrors') {
                await this.viewsService.openView(Markers.MARKERS_VIEW_ID, true);
                return Promise.resolve(TaskRunResult.Failure);
            }
            if (onTaskErrors === 'abort') {
                return Promise.resolve(TaskRunResult.Failure);
            }
            const taskLabel = typeof taskId === 'string' ? taskId : taskId ? taskId.name : '';
            const message = errorCount > 1
                ? ( localize(5378, "Errors exist after running preLaunchTask '{0}'.", taskLabel))
                : errorCount === 1
                    ? ( localize(5379, "Error exists after running preLaunchTask '{0}'.", taskLabel))
                    : taskSummary && typeof taskSummary.exitCode === 'number'
                        ? ( localize(
                5380,
                "The preLaunchTask '{0}' terminated with exit code {1}.",
                taskLabel,
                taskSummary.exitCode
            ))
                        : ( localize(5381, "The preLaunchTask '{0}' terminated.", taskLabel));
            let DebugChoice;
            (function (DebugChoice) {
                DebugChoice[DebugChoice["DebugAnyway"] = 1] = "DebugAnyway";
                DebugChoice[DebugChoice["ShowErrors"] = 2] = "ShowErrors";
                DebugChoice[DebugChoice["Cancel"] = 0] = "Cancel";
            })(DebugChoice || (DebugChoice = {}));
            const { result, checkboxChecked } = await this.dialogService.prompt({
                type: Severity.Warning,
                message,
                buttons: [
                    {
                        label: DEBUG_ANYWAY_LABEL,
                        run: () => DebugChoice.DebugAnyway
                    },
                    {
                        label: ( localize(5382, "&&Show Errors")),
                        run: () => DebugChoice.ShowErrors
                    }
                ],
                cancelButton: {
                    label: ABORT_LABEL,
                    run: () => DebugChoice.Cancel
                },
                checkbox: {
                    label: ( localize(5383, "Remember my choice in user settings")),
                }
            });
            const debugAnyway = result === DebugChoice.DebugAnyway;
            const abort = result === DebugChoice.Cancel;
            if (checkboxChecked) {
                this.configurationService.updateValue('debug.onTaskErrors', result === DebugChoice.DebugAnyway ? 'debugAnyway' : abort ? 'abort' : 'showErrors');
            }
            if (abort) {
                return Promise.resolve(TaskRunResult.Failure);
            }
            if (debugAnyway) {
                return TaskRunResult.Success;
            }
            await this.viewsService.openView(Markers.MARKERS_VIEW_ID, true);
            return Promise.resolve(TaskRunResult.Failure);
        }
        catch (err) {
            const taskConfigureAction = this.taskService.configureAction();
            const choiceMap = JSON.parse(this.storageService.get(DEBUG_TASK_ERROR_CHOICE_KEY, StorageScope.WORKSPACE, '{}'));
            let choice = -1;
            let DebugChoice;
            (function (DebugChoice) {
                DebugChoice[DebugChoice["DebugAnyway"] = 0] = "DebugAnyway";
                DebugChoice[DebugChoice["ConfigureTask"] = 1] = "ConfigureTask";
                DebugChoice[DebugChoice["Cancel"] = 2] = "Cancel";
            })(DebugChoice || (DebugChoice = {}));
            if (choiceMap[err.message] !== undefined) {
                choice = choiceMap[err.message];
            }
            else {
                const { result, checkboxChecked } = await this.dialogService.prompt({
                    type: Severity.Error,
                    message: err.message,
                    buttons: [
                        {
                            label: ( localize(5376, "&&Debug Anyway")),
                            run: () => DebugChoice.DebugAnyway
                        },
                        {
                            label: taskConfigureAction.label,
                            run: () => DebugChoice.ConfigureTask
                        }
                    ],
                    cancelButton: {
                        run: () => DebugChoice.Cancel
                    },
                    checkbox: {
                        label: ( localize(5384, "Remember my choice for this task"))
                    }
                });
                choice = result;
                if (checkboxChecked) {
                    choiceMap[err.message] = choice;
                    this.storageService.store(DEBUG_TASK_ERROR_CHOICE_KEY, JSON.stringify(choiceMap), StorageScope.WORKSPACE, StorageTarget.MACHINE);
                }
            }
            if (choice === DebugChoice.ConfigureTask) {
                await taskConfigureAction.run();
            }
            return choice === DebugChoice.DebugAnyway ? TaskRunResult.Success : TaskRunResult.Failure;
        }
    }
    async runTask(root, taskId, token = this.globalCancellation.token) {
        if (!taskId) {
            return Promise.resolve(null);
        }
        if (!root) {
            return Promise.reject(( new Error(( localize(
                5385,
                "Task '{0}' can not be referenced from a launch configuration that is in a different workspace folder.",
                typeof taskId === 'string' ? taskId : taskId.type
            )))));
        }
        const task = await this.taskService.getTask(root, taskId);
        if (!task) {
            const errorMessage = typeof taskId === 'string'
                ? ( localize(5386, "Could not find the task '{0}'.", taskId))
                : ( localize(5387, "Could not find the specified task."));
            return Promise.reject(createErrorWithActions(errorMessage, [( new Action(
                DEBUG_CONFIGURE_COMMAND_ID,
                DEBUG_CONFIGURE_LABEL,
                undefined,
                true,
                () => this.commandService.executeCommand(DEBUG_CONFIGURE_COMMAND_ID)
            ))]));
        }
        let taskStarted = false;
        const store = ( new DisposableStore());
        const getTaskKey = (t) => t.getKey() ?? t.getMapKey();
        const taskKey = getTaskKey(task);
        const inactivePromise = ( new Promise(
            (resolve) => store.add(onceFilter(this.taskService.onDidStateChange, e => {
                return (e.kind === TaskEventKind.Inactive
                    || (e.kind === TaskEventKind.ProcessEnded && e.exitCode === undefined))
                    && getTaskKey(e.__task) === taskKey;
            })(e => {
                taskStarted = true;
                resolve(e.kind === TaskEventKind.ProcessEnded ? { exitCode: e.exitCode } : null);
            }))
        ));
        store.add(onceFilter(this.taskService.onDidStateChange, e => ((e.kind === TaskEventKind.Active) || (e.kind === TaskEventKind.DependsOnStarted)) && getTaskKey(e.__task) === taskKey)(() => {
            taskStarted = true;
        }));
        const didAcquireInput = store.add(( new Emitter()));
        store.add(onceFilter(this.taskService.onDidStateChange, e => (e.kind === TaskEventKind.AcquiredInput) && getTaskKey(e.__task) === taskKey)(() => didAcquireInput.fire()));
        const taskDonePromise = this.taskService.getActiveTasks().then(async (tasks) => {
            if (tasks.find(t => getTaskKey(t) === taskKey)) {
                didAcquireInput.fire();
                const busyTasks = await this.taskService.getBusyTasks();
                if (busyTasks.find(t => getTaskKey(t) === taskKey)) {
                    taskStarted = true;
                    return inactivePromise;
                }
                return Promise.resolve(null);
            }
            const taskPromise = this.taskService.run(task);
            if (task.configurationProperties.isBackground) {
                return inactivePromise;
            }
            return taskPromise.then(x => x ?? null);
        });
        const result = ( new Promise((resolve, reject) => {
            taskDonePromise.then(result => {
                taskStarted = true;
                resolve(result);
            }, error => reject(error));
            store.add(token.onCancellationRequested(() => {
                resolve({ exitCode: undefined, cancelled: true });
                this.taskService.terminate(task).catch(() => { });
            }));
            store.add(didAcquireInput.event(() => {
                const waitTime = task.configurationProperties.isBackground ? 5000 : 10000;
                store.add(disposableTimeout(() => {
                    if (!taskStarted) {
                        const errorMessage = ( localize(
                            5388,
                            "The task '{0}' has not exited and doesn't have a 'problemMatcher' defined. Make sure to define a problem matcher for watch tasks.",
                            typeof taskId === 'string' ? taskId : JSON.stringify(taskId)
                        ));
                        reject({ severity: Severity.Error, message: errorMessage });
                    }
                }, waitTime));
                const hideSlowPreLaunchWarning = this.configurationService.getValue('debug').hideSlowPreLaunchWarning;
                if (!hideSlowPreLaunchWarning) {
                    store.add(disposableTimeout(() => {
                        const message = ( localize(
                            5389,
                            "Waiting for preLaunchTask '{0}'...",
                            task.configurationProperties.name
                        ));
                        const buttons = [DEBUG_ANYWAY_LABEL_NO_MEMO, ABORT_LABEL];
                        const canConfigure = task instanceof CustomTask || task instanceof ConfiguringTask;
                        if (canConfigure) {
                            buttons.splice(1, 0, ( localize(5390, "Configure Task")));
                        }
                        this.progressService.withProgress({ location: ProgressLocation.Notification, title: message, buttons }, () => result.catch(() => { }), (choice) => {
                            if (choice === undefined) ;
                            else if (choice === 0) {
                                resolve({ exitCode: 0 });
                            }
                            else {
                                resolve({ exitCode: undefined, cancelled: true });
                                this.taskService.terminate(task).catch(() => { });
                                if (canConfigure && choice === 1) {
                                    this.taskService.openConfig(task);
                                }
                            }
                        });
                    }, 10_000));
                }
            }));
        }));
        return result.finally(() => store.dispose());
    }
};
DebugTaskRunner = ( __decorate([
    ( __param(0, ITaskService)),
    ( __param(1, IMarkerService)),
    ( __param(2, IConfigurationService)),
    ( __param(3, IViewsService)),
    ( __param(4, IDialogService)),
    ( __param(5, IStorageService)),
    ( __param(6, ICommandService)),
    ( __param(7, IProgressService))
], DebugTaskRunner));

export { DebugTaskRunner, TaskRunResult };
